[−][src]Struct table_extract::Table
A parsed HTML table.
See the module level documentation for more.
Methods
impl Table[src]
pub fn find_first(html: &str) -> Option<Table>[src]
Finds the first table in html.
pub fn find_by_id(html: &str, id: &str) -> Option<Table>[src]
Finds the table in html with an id of id.
pub fn find_by_headers<T>(html: &str, headers: &[T]) -> Option<Table> where
T: AsRef<str>, [src]
T: AsRef<str>,
Finds the table in html whose first row contains all of the headers
specified in headers. The order does not matter.
If headers is empty, this is the same as
find_first.
pub fn headers(&self) -> &Headers[src]
Returns the headers of the table.
This will be empty if the table had no <th> tags in its first row. See
Headers for more.
ⓘImportant traits for Iter<'a>pub fn iter(&self) -> Iter[src]
ⓘImportant traits for Iter<'a>